@@ -7,7 +7,7 @@
 # the same terms as the Perl 5 programming language system itself.
 # 
 package Dist::Zilla::Plugin::AutoPrereq;
-our $VERSION = '0.2.0';
+our $VERSION = '0.3.0';
 
 # ABSTRACT: automatically extract prereqs from your modules
 
@@ -121,7 +121,7 @@ sub _prereqs_in_file {
 
     # add moose specifics
     my @roles =
-        map { /^(?:with)\s+['"]([\w:]+)['"]/ ? ($1) : () }
+        map { /^(?:with|extends)\s+['"]([\w:]+)['"]/ ? ($1) : () }
         @lines;
     @prereqs{ @roles } = (0) x @roles;
 
@@ -160,7 +160,7 @@ Dist::Zilla::Plugin::AutoPrereq - automatically extract prereqs from your module
 
 =head1 VERSION
 
-version 0.2.0
+version 0.3.0
 
 =begin Pod::Coverage
 
@@ -188,6 +188,9 @@ following prereqs:
 =item * plain lines beginning with C<use> or C<require> in your perl
 modules and scripts.
 
+=item * L<Moose> inheritance declared with the C<extends> keyword
+(warning: only the first one is currently extracted).
+
 =item * L<Moose> roles included with the C<with> keyword.
 
 =back 
